<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="88px">
      <el-form-item label="物料类型" prop="pid">
        <el-select v-model="queryParams.pid" size="small" @change="onInput()">
          <el-option
            v-for="item in dictypeList"
            :key="item.id"
            :label="item.signType"
            :value="item.id"
          />
        </el-select>
      </el-form-item>
<!---->
      <el-form-item label="物料名称" prop="signName">
        <el-input
          v-model="queryParams.signName"
          placeholder="请输入物料名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
          @input="onInput()"
        />
      </el-form-item>
      <el-form-item label="物料编码" prop="signCode">
        <el-input
          v-model="queryParams.signCode"
          placeholder="请输入物料编码"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
          @input="onInput()"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['guide:dictype:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['guide:dictype:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['guide:dictype:remove']"
        >删除</el-button>
      </el-col>
<!--      <el-col :span="1.5">-->
<!--        <el-button-->
<!--          type="info"-->
<!--          plain-->
<!--          icon="el-icon-upload"-->
<!--          size="mini"-->
<!--          @click="handleImport"-->
<!--        >导入</el-button>-->
<!--      </el-col>-->
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="list" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="ID" align="center" prop="id" />-->
      <el-table-column label="物料名称" align="center" prop="signName" >
      </el-table-column>
      <el-table-column label="物料编码" align="center" prop="signCode" />
      <el-table-column label="物料图片" align="center" prop="type" >
        <template slot-scope="scope">
          <el-image
            :src="scope.row.signPicture"
            :preview-src-list="getSignUrlArray(scope.row.signPicture)"
            style="height: 40px;">
            <div slot="error">
              <span style="color: #999;">暂无图片</span>
            </div>
          </el-image>
        </template>
      </el-table-column>
      <el-table-column label="描述" align="center" prop="remark" />
      <!--      <el-table-column label="扩展" align="center" prop="extend" />-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['guide:dictype:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['guide:dictype:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改物料类型名称对照对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" size="small" label-width="80px">
        <el-form-item label="物料名称" prop="signName">
          <el-input v-model="form.signName" placeholder="请输入物料名称" />
        </el-form-item>
        <el-form-item label="物料图片" prop="signPicture">
          <imageUpload  v-model="form.signPicture" :limit='1'></imageUpload>
        </el-form-item>
        <el-form-item label="描述" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入描述" />
        </el-form-item>
      </el-form>

      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
    import { listDictype, getDictype, delDictype, addDictype, updateDictype, exportDictype } from "@/api/sfa/dictype";
    import { getToken } from "@/utils/auth";
    export default {
        name: "Dictype",
        components: {
        },
        data() {
            return {
                // 遮罩层
                loading: true,
                // 导出遮罩层
                exportLoading: false,
                // 选中数组
                ids: [],
                // 非单个禁用
                single: true,
                // 非多个禁用
                multiple: true,
                // 显示搜索条件
                showSearch: true,
                // 总条数
                total: 0,
                // 物料类型名称对照表格数据
                dictypeList: [],
                list: [],
                // 弹出层标题
                title: "",
                // 是否显示弹出层
                open: false,
                // 查询参数
                queryParams: {
                    pageNum: 1,
                    pageSize: 10,
                    pid: null,
                    type: 1,
                },
                // 表单参数
                form: {},
                // 表单校验
                rules: {
                    signName: [
                        { required: true, message: '请输入物料名称', trigger: 'blur' },
                    ],
                    signPicture:[
                        { required: true, message: "物料图片不能为空", trigger: "change" }
                  ],
                },
            };
        },
        created() {
            const pId = this.$route.params && this.$route.params.id;
            this.queryParams.pid = Number(pId);
            this.getType();
            this.getList();
        },
        methods: {
            onInput(){
                this.$forceUpdate()
            },
            getType() {
                let queryParams = {
                    type:0,
                };
                listDictype(queryParams).then(response => {
                    this.dictypeList = response.rows;
                    this.total = response.total;
                    this.loading = false;
                });
            },
            /** 查询物料类型名称对照列表 */
            getList() {
                this.loading = true;
                listDictype(this.queryParams).then(response => {
                    this.list = response.rows;
                    this.total = response.total;
                    this.loading = false;
                });
            },
            getSignUrlArray(url){
              let urlArray = [];
              urlArray.push(url);
              return urlArray;
            },
            // 取消按钮
            cancel() {
                this.open = false;
                this.reset();
            },
            // 表单重置
            reset() {
                this.form = {};
                this.resetForm("form");
            },
            /** 搜索按钮操作 */
            handleQuery() {
                this.queryParams.pageNum = 1;
                this.getList();
            },
            /** 重置按钮操作 */
            resetQuery() {
                this.queryParams.pid = this.$route.params && this.$route.params.id;
                this.resetForm("queryForm");
                this.handleQuery();
            },
            // 多选框选中数据
            handleSelectionChange(selection) {
                this.ids = selection.map(item => item.id)
                this.single = selection.length!==1
                this.multiple = !selection.length
            },
            /** 新增按钮操作 */
            handleAdd() {
                this.reset();
                this.open = true;
                this.title = "添加物料名称";
            },
            /** 修改按钮操作 */
            handleUpdate(row) {
                this.reset();
                const id = row.id || this.ids
                getDictype(id).then(response => {
                    this.form = response.data;
                    this.open = true;
                    this.title = "修改物料名称";
                });
            },
            /** 提交按钮 */
            submitForm() {
                this.$refs["form"].validate(valid => {
                    if (valid) {
                        this.form.pid = this.queryParams.pid;
                        this.form.type = 1;
                        this.dictypeList.forEach((item)=>{
                            if(item.id == this.queryParams.pid){
                                this.form.signType = item.signType;
                            }
                        })
                        if (this.form.id != null) {
                            updateDictype(this.form).then(response => {
                                this.$modal.msgSuccess("修改成功");
                                this.open = false;
                                this.getList();
                            });
                        } else {
                            addDictype(this.form).then(response => {
                                this.$modal.msgSuccess("新增成功");
                                this.open = false;
                                this.getList();
                            });
                        }
                    }
                });
            },
            /** 删除按钮操作 */
            handleDelete(row) {
                const ids = row.id || this.ids;
                this.$confirm('是否确认删除所选数据项?', "警告", {
                    confirmButtonText: "确定",
                    cancelButtonText: "取消",
                    type: "warning"
                }).then(function() {
                    return delDictype(ids);
                }).then(() => {
                    this.getList();
                    this.$modal.msgSuccess("删除成功");
                }).catch(() => {});
            },
            /** 导出按钮操作 */
            handleExport() {
                const queryParams = this.queryParams;
                this.$confirm('是否确认导出所有物料类型名称对照数据项?', "警告", {
                    confirmButtonText: "确定",
                    cancelButtonText: "取消",
                    type: "warning"
                }).then(() => {
                    this.exportLoading = true;
                    return exportDictype(queryParams);
                }).then(response => {
                    this.download(response.msg);
                    this.exportLoading = false;
                }).catch(() => {});
            },
        }
    };
</script>
